@@ -57,7 +57,7 @@ DEFAULT_CONFIG = {
     "enable_themes_menu": True,
     "enable_sizegrip": True,
     "disable_notebook": True,
-    "default_theme": "Clam",
+    "default_theme": "clam",
 }
 
 def bind_popup(binding, widget, menu):
